// Copyright (c) 2024, Oracle and/or its affiliates. All rights reserved.
// Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl.

resource "oci_core_instance" "gdk_guide_instance" {
  agent_config {
    is_management_disabled = "false"
    is_monitoring_disabled = "false"
    plugins_config {
      desired_state = "DISABLED"
      name          = "Vulnerability Scanning"
    }
    plugins_config {
      desired_state = "DISABLED"
      name          = "Oracle Java Management Service"
    }
    plugins_config {
      desired_state = "ENABLED"
      name          = "OS Management Service Agent"
    }
    plugins_config {
      desired_state = "DISABLED"
      name          = "Management Agent"
    }
    plugins_config {
      desired_state = "ENABLED"
      name          = "Compute Instance Run Command"
    }
    plugins_config {
      desired_state = "ENABLED"
      name          = "Compute Instance Monitoring"
    }
    plugins_config {
      desired_state = "DISABLED"
      name          = "Block Volume Management"
    }
    plugins_config {
      desired_state = "DISABLED"
      name          = "Bastion"
    }
  }
  availability_config {
    is_live_migration_preferred = "true"
    recovery_action             = "RESTORE_INSTANCE"
  }
  availability_domain = local.ad1_name
  compartment_id      = var.compartment_ocid
  create_vnic_details {
    assign_ipv6ip             = "false"
    assign_private_dns_record = "true"
    assign_public_ip          = "true"
    subnet_id                 = oci_core_subnet.developer_subnet.id
  }
  display_name = "GDK_OKE_guide_VM"
  instance_options {
    are_legacy_imds_endpoints_disabled = "false"
  }
  metadata = {
    "ssh_authorized_keys" = "${var.ssh_public_key}\n${tls_private_key.setup_key_pair.public_key_openssh}"
    "user_data"           = "${base64encode(templatefile("${path.module}/gdk_oke_compute_instance_config.tftpl", {}))}"
  }
  shape = "VM.Standard.E4.Flex"
  shape_config {
    baseline_ocpu_utilization = "BASELINE_1_1"
    memory_in_gbs             = "64"
    ocpus                     = "4"
  }
  source_details {
    source_id = data.oci_core_images.target_region_images.images[0].id
    source_type = "image"
  }
  depends_on = [local_file.kube_config]
  provisioner "file" {
    connection {
      agent       = false
      timeout     = "30m"
      host        = oci_core_instance.gdk_guide_instance.public_ip
      user        = "opc"
      private_key = tls_private_key.setup_key_pair.private_key_openssh
    }
    source      = local.kube_config_filename
    destination = "/home/opc/.kube_config"
  }
}
