// Copyright (c) 2024, Oracle and/or its affiliates. All rights reserved.
// Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl.

resource "oci_containerengine_node_pool" "node_pool_1" {
  cluster_id     = oci_containerengine_cluster.generated_oci_containerengine_cluster.id
  compartment_id = var.compartment_ocid
  freeform_tags = {
    "OKEnodePoolName" = "pool1"
  }
  initial_node_labels {
    key   = "name"
    value = "gdk_guide"
  }
  kubernetes_version = var.k8s_version
  name               = "pool1"
  node_config_details {
    freeform_tags = {
      "OKEnodePoolName" = "pool1"
    }
    node_pool_pod_network_option_details {
      cni_type       = "OCI_VCN_IP_NATIVE"
      pod_subnet_ids = [oci_core_subnet.node_subnet.id]
    }
    placement_configs {
      availability_domain = local.ad1_name
      subnet_id           = oci_core_subnet.node_subnet.id
    }
    placement_configs {
      availability_domain = local.ad1_name
      subnet_id           = oci_core_subnet.node_subnet.id
    }
    placement_configs {
      availability_domain = local.ad1_name
      subnet_id           = oci_core_subnet.node_subnet.id
    }
    size = "1"
  }
  node_eviction_node_pool_settings {
    eviction_grace_duration = "PT60M"
  }
  node_shape = "VM.Standard.E4.Flex"
  node_shape_config {
    memory_in_gbs = "16"
    ocpus         = "1"
  }
  node_source_details {
    image_id    = local.lookup_node_image_id_by_name
    source_type = "IMAGE"
  }
}
