// Copyright (c) 2024, Oracle and/or its affiliates. All rights reserved.
// Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl.

variable "tenancy_ocid" {}
variable "region" {}
variable compartment_ocid {}
variable "ssh_public_key" {}

variable "enable_compartment_delete" {
  default = "true"
}

variable "idm_wait_seconds" {
  default = 60
}

variable "repo_api" {
  default = "gdk-k8s/api-oci"
}

variable "repo_orders" {
  default = "gdk-k8s/orders-oci"
}

variable "repo_users" {
  default = "gdk-k8s/users-oci"
}

variable k8s_version {
  default = "v1.29.1"
}

variable node_pool_image_name {
  default = "Oracle-Linux-8.9-2024.01.26-0-OKE-1.29.1-679"
}

locals {
  all_svc_idx = index(
    [for v in data.oci_core_services.oci_services.services : substr(v.name, 0, 4)], "All "
  )
  all_services            = data.oci_core_services.oci_services.services[local.all_svc_idx]
  all_services_cidr_block = local.all_services.cidr_block
  all_services_ocid       = local.all_services.id
  repo_names              = [var.repo_api, var.repo_orders, var.repo_users]
  ad1_name                = data.oci_identity_availability_domain.ad1.name
  # compartment_name        = data.oci_identity_compartment.guide_compartment.name
  # compartment_ocid        = oci_identity_compartment.gdk_oke.id
}

locals {
  kube_config_content     = data.oci_containerengine_cluster_kube_config.cluster_kube_config.content
  kube_config_filename    = "${path.module}/kube_config"
}

locals {
  //lookup image id by name in the target region 
  source_images                = data.oci_containerengine_node_pool_option.node_pool_option.sources
  lookup_node_image_id_by_name = element([
    for img in local.source_images :
      img if img.source_name == var.node_pool_image_name
  ],0).image_id
}